pub async fn download_info(
    __arg0: State<Arc<RwLock<AppState>>>,
    __arg1: Path<String>
) -> impl IntoResponse
Retrieve information about a transfer request based on the transfer name.

Arguments

  • shared_state - The shared state containing the transfer requests.
  • name - The name of the transfer request.

Returns

Returns a response containing the transfer request if found, or a not found response if the transfer request is not found.