Function caesar_core::relay::server::start_ws
source · pub async fn start_ws(port: &i32, listen_addr: &String)Expand description
Start the WebSocket server.
This function initializes the server and starts listening for incoming connections. It configures the routes for the WebSocket handler and the upload and download routes. Additionally, it sets up the tracing layer to log incoming requests.
Arguments
port- The port number to listen on.listen_addr- The IP address to listen on.